Module uim.codec.writer
=======================
Writer
=======
This package contains different encoders for ink formats:

- Universal Ink Model (v3.1.0)

Sub-modules
-----------
* uim.codec.writer.encoder